@@ -28,16 +28,15 @@ class ValidOnlyIfInstantiated:
 		pass
 class InvalidClass:
 	required_string_attribute = 123
-	def required_method():
-		pass
+	required_method = 'not_a_callable'
 	def required_b(self):
 		pass
-simpleschema.validate(ValidClass, my_schema)  # True
-simpleschema.validate(ValidClass(), my_schema)  # True
-simpleschema.validate(ValidOnlyIfInstantiated, my_schema)  # ValueError
-simpleschema.validate(ValidOnlyIfInstantiated(), my_schema)  # True
-simpleschema.validate(InvalidClass, my_schema)  # ValueError
-simpleschema.validate(InvalidClass(), my_schema)  # ValueError
+simpleschema.is_valid(ValidClass, my_schema)  # True
+simpleschema.is_valid(ValidClass(), my_schema)  # True
+simpleschema.is_valid(ValidOnlyIfInstantiated, my_schema)  # False
+simpleschema.is_valid(ValidOnlyIfInstantiated(), my_schema)  # True
+simpleschema.is_valid(InvalidClass, my_schema)  # False
+simpleschema.is_valid(InvalidClass(), my_schema)  # False
 
 	"""
 
